@@ -1,12 +1,13 @@
 /* Copyright (c) 1994 Sun Wu, Udi Manber, Burra Gopal.  All Rights Reserved. */
 #include "agrep.h"
 #include "checkfile.h"
+#include <errno.h>
 
 extern int errno;
 extern CHAR Progname[MAXNAME]; 
 extern int SGREP, PAT_FILE, PAT_BUFFER, EXITONERROR, SIMPLEPATTERN,
 	CONSTANT, D, NOUPPER, JUMP, I, LINENUM, INVERSE, WORDBOUND, WHOLELINE,
-	SILENT, DNA, BESTMATCH;
+	SILENT, DNA, BESTMATCH, DELIMITER;
 
 /* Make it an interface routine that tells you whether mgrep can be used for the pattern or not: must sneak and access global variable D though... */
 int
@@ -126,6 +127,7 @@ outoffor:
 	if (!set && (D>0)) return 0;	/* errors, not simple */
 	if (NOUPPER && (D>0)) return 0;	/* errors, not simple */     
 	if (JUMP == ON) return 0;	/* I, S, D costs, not simple */
+	if (DELIMITER) return 0;        /* delimiters avoid mgrep */
 	if (I == 0) return 0;		/* I has 0 cost not 1, not simple */
 	if (LINENUM) return 0;		/* can't use mgrep, so not simple */
 	if (WORDBOUND && (D > 0)) return 0; /* errors, not simple */  
