@@ -98,7 +98,7 @@ extern char  amatched_terminals[MAXNUM_PAT]; /* which patterns have been matched
 extern int anum_terminals;
 extern int AComplexBoolean;
 static void countline();
-
+void acompute_duplicates();
 #if	DOTCOMPRESSED
 /* Equivalent variables for compression search */
 uchar tc_SHIFT1[MAXMEMBER1];
@@ -1987,7 +1987,7 @@ tc_accumulate()
 #endif	/*DOTCOMPRESSED*/
 
 /* Compute duplicate strings using tr's info, not strcmp! */
-int
+void
 acompute_duplicates(aduplicates, aterminals, anum_terminals, tr)
 	char	aduplicates[MAXNUM_PAT][MAXNUM_PAT];
 	ParseTree aterminals[];
