@@ -110,7 +110,7 @@ extern int initialize_common_done;
 int
 tcompressible(buffer, num_read, flags)
 	char	*buffer;
-	int	*num_read;
+	int	num_read;
 	int	flags;
 {
 	if (!initialize_common_done) {
@@ -133,7 +133,7 @@ tcompressible(buffer, num_read, flags)
 			fprintf(stderr, "Postscript data,");
 		return(0);
 	}
-	if (already_tcompressed(buffer, num_read)) return 0;
+	if (already_tcompressed(buffer, num_read, flags)) return 0;
 	return(1);
 }
 
