@@ -3,7 +3,7 @@
  *
  *  Darren Hardy, hardy@cs.colorado.edu, July 1994
  *
- *  $Id: template.h,v 1.1 1999/11/03 21:40:57 golda Exp $
+ *  $Id: template.h,v 1.2 2006/02/03 16:59:14 golda Exp $
  *
  *  ----------------------------------------------------------------------
  *  Copyright (c) 1994, 1995.  All rights reserved.
@@ -118,11 +118,7 @@ typedef struct template Template;
 #define YEAR	((time_t) MONTH * 12)
 
 #ifndef _PARAMS
-#if defined(__STDC__) || defined(__cplusplus) || defined(__STRICT_ANSI__)
 #define _PARAMS(ARGS) ARGS
-#else /* Traditional C */     
-#define _PARAMS(ARGS) ()      
-#endif /* __STDC__ */              
 #endif /* _PARAMS */   
 
 /* Templates */
