@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: log.c,v 1.3 2004/05/30 23:35:49 golda Exp $";
+static char rcsid[] = "$Id: log.c,v 1.5 2006/02/03 16:53:26 golda Exp $";
 /*
  *  log.c - Logging facilities for Essence system.
  *
@@ -55,11 +55,7 @@ static char rcsid[] = "$Id: log.c,v 1.3 2004/05/30 23:35:49 golda Exp $";
 #include <errno.h>
 #include <time.h>
 #include <sys/file.h>
-#if defined(__STRICT_ANSI__)
 #include <stdarg.h>
-#else
-#include <varargs.h>
-#endif
 #include "util.h"
 
 /* Local functions */
@@ -120,7 +116,6 @@ FILE *a, *b;
  *  glimpselog() - used like printf(3).  Prints message to stdout.
  */
 
-#if defined(__STRICT_ANSI__)
 void glimpselog(char *fmt,...)
 {
 	va_list ap;
@@ -129,19 +124,7 @@ void glimpselog(char *fmt,...)
 		return;
 
 	va_start(ap, fmt);
-#else
-void glimpselog(va_alist)
-va_dcl
-{
-	va_list ap;
-	char *fmt;
 
-	if (fp_log == NULL)
-		return;
-
-	va_start(ap);
-	fmt = va_arg(ap, char *);
-#endif				/* __STRICT_ANSI__ */
 	if (fp_log == NULL)
 		return;
 
@@ -156,7 +139,6 @@ va_dcl
 /*
  *  errorlog() - used like printf(3).  Prints error message to stderr.
  */
-#if defined(__STRICT_ANSI__)
 void errorlog(char *fmt,...)
 {
 	va_list ap;
@@ -165,19 +147,6 @@ void errorlog(char *fmt,...)
 		return;
 
 	va_start(ap, fmt);
-#else
-void errorlog(va_alist)
-va_dcl
-{
-	va_list ap;
-	char *fmt;
-
-	if (fp_errs == NULL)
-		return;
-
-	va_start(ap);
-	fmt = va_arg(ap, char *);
-#endif				/* __STRICT_ANSI__ */
 
 	if (fp_errs == NULL)
 		return;
@@ -194,7 +163,6 @@ va_dcl
 /*
  *  fatal() - used like printf(3).  Prints error message to stderr and exits
  */
-#if defined(__STRICT_ANSI__)
 void fatal(char *fmt,...)
 {
 	va_list ap;
@@ -203,19 +171,6 @@ void fatal(char *fmt,...)
 		exit(1);
 
 	va_start(ap, fmt);
-#else
-void fatal(va_alist)
-va_dcl
-{
-	va_list ap;
-	char *fmt;
-
-	if (fp_errs == NULL)
-		exit(1);
-
-	va_start(ap);
-	fmt = va_arg(ap, char *);
-#endif				/* __STRICT_ANSI__ */
 
 	if (fp_errs == NULL)
 		exit(1);
